Operator precedence definitions and utilities.
This namespace defines the precedence and associativity rules for all infix operators supported by the library. Higher precedence numbers indicate higher precedence (bind more tightly).
Operator precedence definitions and utilities. This namespace defines the precedence and associativity rules for all infix operators supported by the library. Higher precedence numbers indicate higher precedence (bind more tightly).
(left-associative? op)Check if operator is left-associative.
Check if operator is left-associative.
(precedence op)Get precedence value for an operator.
Get precedence value for an operator.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |