infix.precedence

Operator precedence definitions and utilities.

This namespace defines the precedence and associativity rules for all infix operators supported by the library. Higher precedence numbers indicate higher precedence (bind more tightly).

Operator precedence definitions and utilities.

This namespace defines the precedence and associativity rules for all
infix operators supported by the library. Higher precedence numbers
indicate higher precedence (bind more tightly).
raw docstring

left-associative?clj

(left-associative? op)

Check if operator is left-associative.

Check if operator is left-associative.
sourceraw docstring

precedenceclj

(precedence op)

Get precedence value for an operator.

Get precedence value for an operator.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries